@@ -5,7 +5,7 @@ package WWW::YaCyBlacklist;
 # ABSTRACT: a Perl module to parse and execute YaCy blacklists
 
 our $AUTHORITY = 'cpan:IBRAUN';
-$WWW::YaCyBlacklist::VERSION = '0.2';
+$WWW::YaCyBlacklist::VERSION = '0.3';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -201,7 +201,7 @@ WWW::YaCyBlacklist - a Perl module to parse and execute YaCy blacklists
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -240,7 +240,7 @@ C<host> part is a regular expression (but the patterns remain in the list).
 
 =head2 C<filename =E<gt> '/path/to/file.black'> (default C<ycb.black>)
 
-This is file printed by C<store_list>
+This is the file printed by C<store_list>
 
 =head2 C<sortorder =E<gt>  0|1> (default C<0>)
 
@@ -287,9 +287,17 @@ Returns a list of patterns configured by C<sorting> and C<sortorder>.
 
 Prints the current list to a file. Executes C<sort_list( )>.
 
-=head1 Bugs
+=head1 OPERATIONAL NOTES
 
-YaCy does not allow host patterns with to stars at the time being. C<WWW::YaCyBlacklist> does not check for this but simply executes.
+The error
+
+    ^* matches null string many times in regex; marked by <-- HERE in m/^^* <-- HERE
+
+is probably caused by a corrupted path part of a pattern in your list (C<*> instead of C<.*>).
+
+=head1 BUGS
+
+YaCy does not allow host patterns with to stars at the time being. C<WWW::YaCyBlacklist> does not check for this but simply executes. This is rather a YaCy bug.
 
 If there is something you would like to tell me, there are different channels for you:
 
@@ -313,20 +321,34 @@ L<Contact form on my homepage|https://ingram-braun.net/erga/legal-notice-and-con
 
 =back
 
-=head1 Source
-
-L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
-
-=head1 See also
+=head1 SOURCE
 
 =over
 
 =item *
 
+L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
+
+=item *
+
 L<Dev:APIlist|https://wiki.yacy.net/index.php/Dev:APIlist>
 
 =back
 
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<YaCy homepage|https://yacy.net/>
+
+=item *
+
+L<YaCy community|https://community.searchlab.eu/>
+
+=back
+
 =head1 AUTHOR
 
 Ingram Braun <carlorff1@gmail.com>
